/* common.h
   Shared header file for the xmltools package
   Requires Expat (commonly packaged as xmltok-dev)
   Copyright (C) 1999 Linus Walleij

This file is part of the Yelah xmltools package.

Yelah xmltools is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

You should have received a copy of the GNU General Public License
along with Yelah xmltools; see the file COPYING.  If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA. 

*/

#ifndef COMMON_INCLUDED
#define COMMON_INCLUDED 1

#include <config.h>

#if HAVE_STDBOOL_H
# include <stdbool.h>
#else
typedef enum {false = 0, true = 1} bool;
#endif
#include <stdio.h>
#if HAVE_STRING_H
# include <string.h>
#endif
#if HAVE_STDLIB_H
# include <stdlib.h>
#endif
#if HAVE_EXPAT_H
# include <expat.h>
#else
# include <xmlparse.h>
#endif
#include <recode.h>
#define STR_MAXLEN      255
#define BUFFSIZE        8192

/* Global write-file */
FILE* OutFile;

/* This one signs throughput or not on chars and entities */
int CharThroughPut;

/* Language handling */
char *cFixLangCode(const char *inStr);
char *cGetLLanguage(const char *cLangCode);
char *cGetLContents(const char *cLangCode);
char *cGetLImage(const char *cLangCode);
char *cGetLFootnotes(const char *cLangCode);

/* Buffer handlers */
int XMLIterations;               /* Number of times to iterate XML input       */
bool LineBreakMode;              /* Break lines (nice wrapping) or not?        */
int IndentChars;                 /* Number of spaces indenting each line       */
int FootnoteNo;                  /* Current FootNote number                    */
bool StackMode;                  /* Set to 1 and all output goes in stack file */
bool PreserveWhitespace;         /* To preserve whitespace on output           */
bool ExtractToc;                 /* Extract a Table of Contents                */
FILE* FootnoteStackFile;         /* This is where footnotes go                 */
char LineBuffer[160];            /* Intermediate storage                       */
char ExtractChapter[128];        /* Name of chapter to extract                 */
void SetStackMode();             /* To sign that output is to be stacked       */
void UnSetStackMode();           /* Reverse the function above                 */
void OutString(char *fmt, ...);  /* Function to output strings                 */
void OutChar(char c);            /* Function to output individual chars        */

/* Functions to be implemented by all filters */

void startElementHandler(void *data, const XML_Char *el, const XML_Char **attr);
void endElementHandler(void *data, const XML_Char *el);
void textHandler(void *data, const XML_Char *text, int length);
void defaultHandler(void *userData, const XML_Char *s, int length);
void ScanToolOptions(const char **argv, int arg);
void PrintToolHelp(void);

/* Recode engines and requests */
RECODE_OUTER recode_engine_outer;
RECODE_REQUEST recode_engine_request_1;
RECODE_REQUEST recode_engine_request_2;
/* Identifier for recode, must have program name */
char *program_name;

#endif
